@@ -5,10 +5,10 @@ A Command Line Wrapper to allow easy use of pyicloud for
 command line scripts, and related.
 """
 from __future__ import print_function
+from builtins import input
 import argparse
 import pickle
 import sys
-import six
 
 from click import confirm
 
@@ -16,12 +16,6 @@ from pyicloud import PyiCloudService
 from pyicloud.exceptions import PyiCloudFailedLoginException
 from . import utils
 
-# fmt: off
-if six.PY2:
-    input = raw_input  # pylint: disable=redefined-builtin,invalid-name,undefined-variable
-else:
-    input = input  # pylint: disable=bad-option-value,self-assigning-variable,invalid-name
-# fmt: on
 
 DEVICE_ERROR = "Please use the --device switch to indicate which device to use."
 
@@ -207,7 +201,22 @@ def main(args=None):
             ):
                 utils.store_password_in_keyring(username, password)
 
-            if api.requires_2sa:
+            if api.requires_2fa:
+                # fmt: off
+                print(
+                    "\nTwo-step authentication required.",
+                    "\nPlease enter validation code"
+                )
+                # fmt: on
+
+                code = input("(string) --> ")
+                if not api.validate_2fa_code(code):
+                    print("Failed to verify verification code")
+                    sys.exit(1)
+
+                print("")
+
+            elif api.requires_2sa:
                 # fmt: off
                 print(
                     "\nTwo-step authentication required.",
