@@ -1,14 +1,16 @@
 """Photo service."""
-import sys
 import json
 import base64
+from six import PY2
+
+# fmt: off
+from six.moves.urllib.parse import urlencode  # pylint: disable=bad-option-value,relative-import
+# fmt: on
 
 from datetime import datetime
 from pyicloud.exceptions import PyiCloudServiceNotActivatedException
 from pytz import UTC
 
-from future.moves.urllib.parse import urlencode
-
 
 class PhotosService(object):
     """The 'Photos' iCloud service."""
@@ -171,6 +173,11 @@ class PhotosService(object):
             }
 
             for folder in self._fetch_folders():
+
+                # Skiping albums having null name, that can happen sometime
+                if "albumNameEnc" not in folder["fields"]:
+                    continue
+
                 # TODO: Handle subfolders  # pylint: disable=fixme
                 if folder["recordName"] == "----Root-Folder----" or (
                     folder["fields"].get("isDeleted")
@@ -473,9 +480,9 @@ class PhotoAlbum(object):
 
     def __str__(self):
         as_unicode = self.__unicode__()
-        if sys.version_info[0] >= 3:
-            return as_unicode
-        return as_unicode.encode("utf-8", "ignore")
+        if PY2:
+            return as_unicode.encode("utf-8", "ignore")
+        return as_unicode
 
     def __repr__(self):
         return "<%s: '%s'>" % (type(self).__name__, self)
